==> aws-cdk.aws-neptune-alpha-2.4.0a0.tar.gz: package/lib/parameter-group.d.ts <==
import { IResource, Resource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Properties for a parameter group
 */
interface ParameterGroupPropsBase {
    /**
     * (experimental) Description for this parameter group.
     *
     * @default a CDK generated description
     * @experimental
     */
    readonly description?: string;
    /**
     * (experimental) The parameters in this parameter group.
     *
     * @experimental
     */
    readonly parameters: {
        [key: string]: string;
    };
}
/**
 * (experimental) Marker class for cluster parameter group.
 *
 * @experimental
 */
export interface ClusterParameterGroupProps extends ParameterGroupPropsBase {
    /**
     * (experimental) The name of the parameter group.
     *
     * @default A CDK generated name for the parameter group
     * @experimental
     */
    readonly clusterParameterGroupName?: string;
}
/**
 * (experimental) Marker class for cluster parameter group.
 *
 * @experimental
 */
export interface ParameterGroupProps extends ParameterGroupPropsBase {
    /**
     * (experimental) The name of the parameter group.
     *
     * @default A CDK generated name for the parameter group
     * @experimental
     */
    readonly parameterGroupName?: string;
}
/**
 * (experimental) A parameter group.
 *
 * @experimental
 */
export interface IClusterParameterGroup extends IResource {
    /**
     * (experimental) The name of this parameter group.
     *
     * @experimental
     */
    readonly clusterParameterGroupName: string;
}
/**
 * (experimental) A cluster parameter group.
 *
 * @experimental
 * @resource AWS::Neptune::DBClusterParameterGroup
 */
export declare class ClusterParameterGroup extends Resource implements IClusterParameterGroup {
    /**
     * (experimental) Imports a parameter group.
     *
     * @experimental
     */
    static fromClusterParameterGroupName(scope: Construct, id: string, clusterParameterGroupName: string): IClusterParameterGroup;
    /**
     * (experimental) The name of the parameter group.
     *
     * @experimental
     */
    readonly clusterParameterGroupName: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: ClusterParameterGroupProps);
}
/**
 * (experimental) A parameter group.
 *
 * @experimental
 */
export interface IParameterGroup extends IResource {
    /**
     * (experimental) The name of this parameter group.
     *
     * @experimental
     */
    readonly parameterGroupName: string;
}
/**
 * (experimental) DB parameter group.
 *
 * @experimental
 * @resource AWS::Neptune::DBParameterGroup
 */
export declare class ParameterGroup extends Resource implements IParameterGroup {
    /**
     * (experimental) Imports a parameter group.
     *
     * @experimental
     */
    static fromParameterGroupName(scope: Construct, id: string, parameterGroupName: string): IParameterGroup;
    /**
     * (experimental) The name of the parameter group.
     *
     * @experimental
     */
    readonly parameterGroupName: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: ParameterGroupProps);
}
export {};

==> aws-cdk.aws-neptune-alpha-2.24.0a0.tar.gz: package/lib/parameter-group.d.ts <==
import { IResource, Resource } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Properties for a parameter group
 */
interface ParameterGroupPropsBase {
    /**
     * Description for this parameter group
     *
     * @default a CDK generated description
     */
    readonly description?: string;
    /**
     * The parameters in this parameter group
     */
    readonly parameters: {
        [key: string]: string;
    };
}
/**
 * Marker class for cluster parameter group
 */
export interface ClusterParameterGroupProps extends ParameterGroupPropsBase {
    /**
     * The name of the parameter group
     *
     * @default A CDK generated name for the parameter group
     */
    readonly clusterParameterGroupName?: string;
}
/**
 * Marker class for cluster parameter group
 */
export interface ParameterGroupProps extends ParameterGroupPropsBase {
    /**
     * The name of the parameter group
     *
     * @default A CDK generated name for the parameter group
     */
    readonly parameterGroupName?: string;
}
/**
 * A parameter group
 */
export interface IClusterParameterGroup extends IResource {
    /**
     * The name of this parameter group
     */
    readonly clusterParameterGroupName: string;
}
/**
 * A cluster parameter group
 *
 * @resource AWS::Neptune::DBClusterParameterGroup
 */
export declare class ClusterParameterGroup extends Resource implements IClusterParameterGroup {
    /**
     * Imports a parameter group
     */
    static fromClusterParameterGroupName(scope: Construct, id: string, clusterParameterGroupName: string): IClusterParameterGroup;
    /**
     * The name of the parameter group
     */
    readonly clusterParameterGroupName: string;
    constructor(scope: Construct, id: string, props: ClusterParameterGroupProps);
}
/**
 * A parameter group
 */
export interface IParameterGroup extends IResource {
    /**
     * The name of this parameter group
     */
    readonly parameterGroupName: string;
}
/**
 * DB parameter group
 *
 * @resource AWS::Neptune::DBParameterGroup
 */
export declare class ParameterGroup extends Resource implements IParameterGroup {
    /**
     * Imports a parameter group
     */
    static fromParameterGroupName(scope: Construct, id: string, parameterGroupName: string): IParameterGroup;
    /**
     * The name of the parameter group
     */
    readonly parameterGroupName: string;
    constructor(scope: Construct, id: string, props: ParameterGroupProps);
}
export {};
